import logging
import tempfile
from os import remove

from tomato_lib import send_payload

logger = logging.getLogger("tomato")


state = {
    "created": False,
    "path": None,
}


def pytest_load_initial_conftests(args):
    if '--junit-xml' in args or '--junitxml' in args:
        return
    fp = tempfile.NamedTemporaryFile(delete=False)
    logger.info('Creating tomato.xml file due to missing --junit-xml flag')
    state["created"] = True
    state["path"] = fp.name
    fp.close()
    args[:] = ["--junit-xml", state["path"]] + args


def pytest_sessionfinish(session):
    if session.config.option.xmlpath is None:
        logger.warning("Tomato plugin disabled due to missing --junit-xml flag")
        return
    send_payload(session.config.option.xmlpath)
    if state["created"] is True:
        remove(state["path"])
    return



from setuptools import find_packages, setup

install_requires = ["tomato-lib==1.0.7"]


try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except Exception:
    long_description = ''

setup(
    name="pytest-tomato",
    version='1.0.7',
    description="",
    long_description=long_description,
    author="Moshe Zada",
    url="https://github.com/moshe/python-tomato",
    platforms=["linux", "osx", "win32"],
    packages=find_packages(exclude=["testing", "example"]),
    entry_points={
        "pytest11": ["tomato = pytest_tomato.plugin"]
    },
    zip_safe=False,
    python_requires=">=2.7, !=3.0.*, !=3.1.*, !=3.2.*, !=3.3.*",
    install_requires=install_requires,
    setup_requires=[],
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Framework :: Pytest",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: MIT License",
        "Operating System :: POSIX",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: MacOS :: MacOS X",
        "Topic :: Software Development :: Testing",
        "Topic :: Software Development :: Quality Assurance",
        "Topic :: Utilities",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.4",
        "Programming Language :: Python :: 3.5",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
)
